@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Apr 2000
 ;;;;
-;;;; $Id: io.lisp 10151 2004-11-11 21:58:12Z kevin $
+;;;; $Id: io.lisp 11317 2006-11-26 19:04:23Z kevin $
 ;;;;
 ;;;; This file, part of KMRCL, is Copyright (c) 2002-2003 by Kevin M. Rosenberg
 ;;;;
@@ -39,9 +39,8 @@
 	
 (defun read-file-to-string (file)
   "Opens a reads a file. Returns the contents as a single string"
-  (with-output-to-string (out)
-    (with-open-file (in file :direction :input)
-      (read-stream-to-string in))))
+  (with-open-file (in file :direction :input)
+    (read-stream-to-string in)))
 
 (defun read-file-to-usb8-array (file)
   "Opens a reads a file. Returns the contents as single unsigned-byte array"
