@@ -7,9 +7,9 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Apr 2000
 ;;;;
-;;;; $Id: package.lisp 10470 2005-04-26 21:46:09Z kevin $
+;;;; $Id: package.lisp 11323 2006-11-29 17:31:47Z kevin $
 ;;;;
-;;;; This file, part of KMRCL, is Copyright (c) 2002 by Kevin M. Rosenberg
+;;;; This file, part of KMRCL, is Copyright (c) 2002-2006 by Kevin M. Rosenberg
 ;;;;
 ;;;; KMRCL users are granted the rights to distribute and use this software
 ;;;; as governed by the terms of the Lisp Lesser GNU Public License
@@ -49,6 +49,7 @@
    #:string-delimited-string-to-list
    #:list-to-delimited-string
    #:prefixed-fixnum-string
+   #:prefixed-integer-string
    #:integer-string
    #:fast-string-search
    #:string-substitute
@@ -60,6 +61,7 @@
    #:charhex
    #:encode-uri-string
    #:decode-uri-string
+   #:uri-query-to-alist
    #:non-alphanumericp
    #:random-string
    #:first-char
@@ -73,7 +75,8 @@
    #:collapse-whitespace
    #:string->list
    #:trim-non-alphanumeric
-   
+   #:binary-sequence-to-hex-string
+
    ;; io.lisp
    #:indent-spaces
    #:indent-html-spaces
@@ -107,7 +110,7 @@
    #:zone
    #:day-of-month
    #:day-of-week
-   #:+datetime-number-strings+   
+   #:+datetime-number-strings+
    #:utc-offset
    #:copy-binary-stream
 
@@ -137,10 +140,10 @@
    #:get-plist
    #:flatten
    #:unique-slot-values
-   
+
    ;; seq.lisp
    #:nsubseq
-   
+
    ;; math.lisp
    #:ensure-integer
    #:histogram
@@ -173,7 +176,7 @@
    #:ppmx
    #:defconstant*
    #:defvar-unbound
-   
+
    ;; files.lisp
    #:print-file-contents
    #:read-stream-to-string
@@ -181,7 +184,7 @@
    #:read-file-to-usb8-array
    #:read-stream-to-strings
    #:read-file-to-strings
-   
+
    ;; strings.lisp
    #:string-append
    #:count-string-words
@@ -205,11 +208,11 @@
    #:print-separated-strings
    #:lex-string
    #:split-alphanumeric-string
-   
+
    ;; strmatch.lisp
    #:score-multiword-match
    #:multiword-match
-   
+
    ;; symbols.lisp
    #:ensure-keyword
    #:ensure-keyword-upcase
@@ -219,7 +222,7 @@
    #:show
    #:show-variables
    #:show-functions
-   
+
    ;; From attrib-class.lisp
    #:attributes-class
    #:slot-attribute
@@ -228,10 +231,10 @@
    #:generalized-equal
 
    ;; From buffered input
-   
+
    #:make-fields-buffer
    #:read-buffered-fields
-   
+
    ;; From datetime.lisp
    #:pretty-date
    #:date-string
@@ -239,15 +242,15 @@
    #:print-seconds
    #:posix-time-to-utime
    #:utime-to-posix-time
-   
+
    ;; From random.lisp
    #:seed-random-generator
    #:random-choice
-   
+
    ;; From repl.lisp
    #:make-repl
    #:init/repl
-   
+
    ;; From web-utils
    #:*base-url*
    #:base-url!
@@ -258,14 +261,14 @@
    #:user-agent-ie-p
    #:decode-uri-query-string
    #:split-uri-query-string
-   
+
    ;; From xml-utils
    #:sgml-header-stream
    #:xml-tag-contents
    #:positions-xml-tag-contents
    #:cdata-string
    #:write-cdata
-   
+
    ;; From console
    #:*console-msgs*
    #:cmsg
@@ -283,12 +286,12 @@
    ;; sockets.lisp
    #:make-active-socket
    #:close-active-socket
-   
+
    ;; listener.lisp
    #:init/listener
    #:stop-all/listener
    #:listener
-   
+
    ;; fformat.lisp
    #:fformat
 
