@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  June 2003
 ;;;;
-;;;; $Id: processes.lisp 10361 2005-03-19 21:40:21Z kevin $
+;;;; $Id: processes.lisp 10985 2006-07-26 18:52:03Z kevin $
 ;;;; *************************************************************************
 
 (in-package #:kmrcl)
@@ -17,7 +17,7 @@
   #+allegro (mp:process-run-function name func)
   #+cmu (mp:make-process func :name name)
   #+lispworks (mp:process-run-function name nil func)
-  #+sb-thread (sb-thread:make-thread func)
+  #+sb-thread (sb-thread:make-thread func :name name)
   #+openmcl (ccl:process-run-function name func)
   #-(or allegro cmu lispworks sb-thread openmcl) (funcall func)
   )
