@@ -7,9 +7,9 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Apr 2000
 ;;;;
-;;;; $Id: strings.lisp 10072 2004-10-01 04:01:58Z kevin $
+;;;; $Id: strings.lisp 11323 2006-11-29 17:31:47Z kevin $
 ;;;;
-;;;; This file, part of KMRCL, is Copyright (c) 2002 by Kevin M. Rosenberg
+;;;; This file, part of KMRCL, is Copyright (c) 2002-2006 by Kevin M. Rosenberg
 ;;;;
 ;;;; KMRCL users are granted the rights to distribute and use this software
 ;;;; as governed by the terms of the Lisp Lesser GNU Public License
@@ -61,7 +61,7 @@
     (declare (fixnum i))
     (when (char/= char (schar string i)) (return i))))
 
-(defun delimited-string-to-list (string &optional (separator #\space) 
+(defun delimited-string-to-list (string &optional (separator #\space)
 						  skip-terminal)
   "split a string with delimiter"
   (declare (optimize (speed 3) (safety 0) (space 0) (compilation-speed 0))
@@ -106,7 +106,7 @@
 (defun escape-backslashes (s)
   (substitute-string-for-char s #\\ "\\\\"))
 
-(defun substitute-string-for-char (procstr match-char subst-str) 
+(defun substitute-string-for-char (procstr match-char subst-str)
   "Substitutes a string for a single matching character of a string"
   (substitute-chars-strings procstr (list (cons match-char subst-str))))
 
@@ -157,7 +157,7 @@
 			     #+allegro #\%space
 			     #+lispworks #\No-Break-Space))
 
-(defun is-char-whitespace (c) 
+(defun is-char-whitespace (c)
   (declare (character c) (optimize (speed 3) (safety 0)))
   (or (char= c #\Space) (char= c #\Tab) (char= c #\Return)
       (char= c #\Linefeed)
@@ -277,27 +277,40 @@ list of characters and replacement strings."
       (unless (and last-elem last-list)
 	(write-string separator strm)))))
 
-(defun prefixed-fixnum-string (num pchar len)
-  "Outputs a string of LEN digit with an optional initial character PCHAR.
-Leading zeros are present."
-  (declare (optimize (speed 3) (safety 0) (space 0))
-	   (type fixnum num len))
-  (when pchar
-    (incf len))
-  (do* ((zero-code (char-code #\0))
-	(result (make-string len :initial-element #\0))
-	(minus? (minusp num))
-	(val (if minus? (- num) num)
-	     (nth-value 0 (floor val 10)))
-	(pos (1- len) (1- pos))
-	(mod (mod val 10) (mod val 10)))
-      ((or (zerop val) (minusp pos))
+(eval-when (:compile-toplevel :load-toplevel :execute)
+  (defmacro def-prefixed-number-string (fn-name type &optional doc)
+    `(defun ,fn-name (num pchar len)
+       ,@(when (stringp doc) (list doc))
+       (declare (optimize (speed 3) (safety 0) (space 0))
+                (fixnum len)
+                (,type num))
        (when pchar
-	 (setf (schar result 0) pchar))
-       (when minus? (setf (schar result (if pchar 1 0)) #\-))
-       result)
-    (declare (fixnum val mod zero-code pos) (simple-string result))
-    (setf (schar result pos) (code-char (+ zero-code mod)))))
+         (incf len))
+       (do* ((zero-code (char-code #\0))
+           (result (make-string len :initial-element #\0))
+           (minus? (minusp num))
+           (val (if minus? (- num) num)
+                (nth-value 0 (floor val 10)))
+           (pos (1- len) (1- pos))
+           (mod (mod val 10) (mod val 10)))
+         ((or (zerop val) (minusp pos))
+          (when pchar
+            (setf (schar result 0) pchar))
+          (when minus? (setf (schar result (if pchar 1 0)) #\-))
+          result)
+       (declare (,type val) 
+                (fixnum mod zero-code pos)
+                (boolean minus?)
+                (simple-string result))
+       (setf (schar result pos) (code-char (the fixnum (+ zero-code mod))))))))
+
+(def-prefixed-number-string prefixed-fixnum-string fixnum
+ "Outputs a string of LEN digit with an optional initial character PCHAR.
+Leading zeros are present. LEN must be a fixnum.")
+
+(def-prefixed-number-string prefixed-integer-string integer
+ "Outputs a string of LEN digit with an optional initial character PCHAR.
+Leading zeros are present. LEN must be an integer.")
 
 (defun integer-string (num len)
   "Outputs a string of LEN digit with an optional initial character PCHAR.
@@ -353,7 +366,7 @@ Leading zeros are present."
 	     (type (or fixnum null) end))
     (push (subseq str pos end) output)
     (setq pos (+ end substr-len))))
-  
+
 (defun string-to-list-skip-delimiter (str &optional (delim #\space))
   "Return a list of strings, delimited by spaces, skipping spaces."
   (declare (simple-string str)
@@ -425,11 +438,17 @@ for characters in a string"
 (defun charhex (ch)
   "convert hex character to decimal"
   (let ((code (char-code (char-upcase ch))))
-    (declare (fixnum ch)) 
+    (declare (fixnum ch))
     (if (>= code +char-code-upper-a+)
 	(+ 10 (- code +char-code-upper-a+))
 	(- code +char-code-0+))))
 
+(defun binary-sequence-to-hex-string (seq)
+  (let ((list (etypecase seq
+                (list seq)
+                (sequence (map 'list #'identity seq)))))
+    (string-downcase (format nil "~{~2,'0X~}" list))))
+
 (defun encode-uri-string (query)
   "Escape non-alphanumeric characters for URI fields"
   (declare (simple-string query)
@@ -477,6 +496,13 @@ for characters in a string"
 	(setf (schar str dpos) ch)))))
 
 
+(defun uri-query-to-alist (query)
+  "Converts non-decoded URI query to an alist of settings"
+  (mapcar (lambda (set)
+            (let ((lst (kmrcl:delimited-string-to-list set #\=)))
+              (cons (first lst) (second lst))))
+          (kmrcl:delimited-string-to-list
+           (kmrcl:decode-uri-string query) #\&)))
 
 (eval-when (:compile-toplevel :load-toplevel :execute)
   (defvar +unambiguous-charset+
@@ -501,7 +527,7 @@ for characters in a string"
        (if (>= n 26)
 	   (code-char (+ +char-code-upper-a+ (- n 26)))
 	 (code-char (+ +char-code-lower-a+ n)))))))
-     
+
 
 (defun random-string (&key (length 10) (set :lower-alpha))
   "Returns a random lower-case string."
@@ -552,7 +578,7 @@ for characters in a string"
 					      (length ending)))))
 	(return-from string-strip-ending
 	  (subseq str 0 (- len (length ending))))))))
-       
+
 
 (defun string-maybe-shorten (str maxlen)
   (string-elide str maxlen :end))
@@ -569,7 +595,7 @@ for characters in a string"
      ((eq position :middle)
       (multiple-value-bind (mid remain) (truncate maxlen 2)
 	(let ((end1 (- mid 1))
-	      (start2 (- len (- mid 2) remain))) 
+	      (start2 (- len (- mid 2) remain)))
 	  (concatenate 'string (subseq str 0 end1) "..." (subseq str start2)))))
      ((or (eq position :end) t)
       (concatenate 'string (subseq str 0 (- maxlen 3)) "...")))))
@@ -594,7 +620,7 @@ for characters in a string"
   (flet ((is-sep (char) (member char whitespace :test #'char=)))
     (let ((tokens nil))
       (do* ((token-start
-             (position-if-not #'is-sep string) 
+             (position-if-not #'is-sep string)
              (when token-end
                (position-if-not #'is-sep string :start (1+ token-end))))
             (token-end
@@ -609,13 +635,13 @@ for characters in a string"
   "Separates a string at any non-alphanumeric chararacter"
   (declare (simple-string string)
 	   (optimize (speed 3) (safety 0)))
-  (flet ((is-sep (char) 
+  (flet ((is-sep (char)
 	   (declare (character char))
 	   (and (non-alphanumericp char)
 		(not (char= #\_ char)))))
     (let ((tokens nil))
       (do* ((token-start
-             (position-if-not #'is-sep string) 
+             (position-if-not #'is-sep string)
              (when token-end
                (position-if-not #'is-sep string :start (1+ token-end))))
             (token-end
@@ -650,7 +676,7 @@ for characters in a string"
 	(subseq word start end)
       word)))
 
-	  
+
 (defun collapse-whitespace (s)
   "Convert multiple whitespace characters to a single space character."
   (declare (simple-string s)
