@@ -7,9 +7,9 @@
 ;;;; Author:        Kevin M. Rosenberg
 ;;;; Date Started:  Apr 2003
 ;;;;
-;;;; $Id: tests.lisp 10504 2005-04-30 10:14:18Z kevin $
+;;;; $Id: tests.lisp 11092 2006-09-05 01:32:56Z kevin $
 ;;;;
-;;;; This file is Copyright (c) 2000-2002 by Kevin M. Rosenberg
+;;;; This file is Copyright (c) 2000-2006 by Kevin M. Rosenberg
 ;;;;
 ;;;; *************************************************************************
 
@@ -64,6 +64,22 @@
 (deftest :sdstl.4 (string-delimited-string-to-list "ab|cd|ef" "ab")
   ("" "|cd|ef"))
 
+(deftest :hexstr.1 (binary-sequence-to-hex-string ())
+  "")
+
+(deftest :hexstr.2 (binary-sequence-to-hex-string #())
+  "")
+
+(deftest :hexstr.3 (binary-sequence-to-hex-string #(165))
+  "a5"
+)
+
+(deftest :hexstr.4 (binary-sequence-to-hex-string (list 165))
+  "a5")
+
+(deftest :hexstr.5 (binary-sequence-to-hex-string #(165 86))
+  "a556")
+
 (deftest :apsl.1 (append-sublists '((a b) (c d))) (a b c d))
 (deftest :apsl.2 (append-sublists nil) nil)
 (deftest :apsl.3 (append-sublists '((a b))) (a b))
@@ -404,7 +420,14 @@
 (deftest :nwp.2
        (numbers-within-percentage 1. 1.1 11)
   t)
-  
+
+(deftest :pfs.1 (prefixed-fixnum-string 0 #\A 5) "A00000")
+
+(deftest :pfs.2 (prefixed-fixnum-string 1 #\A 5) "A00001")
+
+(deftest :pfs.3 (prefixed-fixnum-string 21 #\B 3) "B021")
+	   
+(deftest :pis.4 (prefixed-integer-string 234134 #\C 7) "C0234134")
 	   
  ;;; MOP Testing
 
